#[non_exhaustive]pub struct CreateNamedQueryInput {
pub name: Option<String>,
pub description: Option<String>,
pub database: Option<String>,
pub query_string: Option<String>,
pub client_request_token: Option<String>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The query name.
description: Option<String>The query description.
database: Option<String>The database to which the query belongs.
query_string: Option<String>The contents of the query with all query statements.
client_request_token: Option<String>A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
work_group: Option<String>The name of the workgroup in which the named query is being created.
Implementations
Sourceimpl CreateNamedQueryInput
impl CreateNamedQueryInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The query description.
Sourcepub fn query_string(&self) -> Option<&str>
pub fn query_string(&self) -> Option<&str>
The contents of the query with all query statements.
Sourcepub fn client_request_token(&self) -> Option<&str>
pub fn client_request_token(&self) -> Option<&str>
A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the workgroup in which the named query is being created.
Sourceimpl CreateNamedQueryInput
impl CreateNamedQueryInput
Sourcepub fn builder() -> CreateNamedQueryInputBuilder
pub fn builder() -> CreateNamedQueryInputBuilder
Creates a new builder-style object to manufacture CreateNamedQueryInput.